@@ -1,13 +1,10 @@
 context("incadoc")
 
-test_that("bmatch", {
-  expect_equal(bmatch(c("hej", "pa", "dig"), "hej"), c(TRUE, FALSE, FALSE))
-  expect_error(bmatch(c("hej", "pa", "dig"), "hejsan"), 
-    "No match. Choose one of")
-})
-
 test_that("find_register", {
-  expect_equal(find_register("all"), "akut lymfatiskt leukemi all") %>% 
+  skip_on_cran()
+  skip_on_appveyor()
+  
+  expect_equal(names(find_register("all")), "akut-lymfatiskt-leukemi-all") %>% 
   expect_silent()
   expect_error(find_register("hejsansvejsan"), 
     "No match. Choose one of")
@@ -20,8 +17,9 @@ test_that("find_documents", {
   skip_on_cran()
   skip_on_appveyor()
   
-  expect_gte(nrow(find_documents("all")), 5)
-  expect_gte(nrow(find_documents("peniscancer", "uppfoljning")), 2)
+  expect_gte(length(find_documents(find_register("all"))), 6)
+  expect_gte(
+    length(find_documents(find_register("peniscancer"), "uppfoljning")), 1)
 })
 
 
@@ -31,10 +29,9 @@ test_that("documents", {
   
   expect_message(
     documents("lunga", "uppfoljning", dir = tempdir(), max_open = 0),
-    "1 files downloaded to"
+    "1 file\\(s\\) downloaded"
   )
   expect_silent(
     documents("lunga", "uppfoljning", dir = tempdir(), max_open = 0))
   
 })
-
